pub struct EffectiveFilesystemLayer<'a> { /* private fields */ }Expand description
One immutable filesystem constraint layer in an effective lowering view.
Implementations
Sourceimpl<'a> EffectiveFilesystemLayer<'a>
impl<'a> EffectiveFilesystemLayer<'a>
Sourcepub const fn mode(&self) -> FilesystemMode
pub const fn mode(&self) -> FilesystemMode
Returns this layer’s enforcement ownership mode.
Sourcepub fn entries(&self) -> &[FilesystemRule]
pub fn entries(&self) -> &[FilesystemRule]
Returns all validated rules in this constraint layer.
Sourcepub const fn glob_scan_max_depth(&self) -> Option<NonZeroUsize>
pub const fn glob_scan_max_depth(&self) -> Option<NonZeroUsize>
Returns the layer’s configured glob scan depth.
Sourcepub fn protected_relative_paths(&self) -> &[PathBuf]
pub fn protected_relative_paths(&self) -> &[PathBuf]
Returns all protected relative paths in this constraint layer.